instrumenttools.InstrumentInventory
===================================

.. inheritance-diagram:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.name

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.append

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.extend

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__contains__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__repr__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.instrumenttools.InstrumentInventory.InstrumentInventory.InstrumentInventory.__setslice__

    Inherited from :py:class:`__builtin__.list`
